// ==================================== Xintf.c ==============================
//  CPU : TMS320F28335-150M
// Ϸ : CCS3.3
// ----------------------------------------------------------------------------
#include "DSP2833x_Device.h"					// Peripheral address definitions
#include "F28335_example.h"					// Main include file

// ======================== EX_BUS Wait  ======================
// [μ] void
// ----------------------------------------------------------------
#pragma CODE_SECTION(InitXintf, "internalMemFuncs")
void InitXintf(void)
{
	asm(" EALLOW");						// Enable EALLOW protected register access
// XCLKOUT to SYSCLKOUT ratio.  By default XCLKOUT = 1/4 SYSCLKOUT
  	// XTIMCLK(75M) = SYSCLKOUT/2
	XintfRegs.XINTCNF2.bit.XTIMCLK = 1;
	// XCLKOUT(37.5M) = XTIMCLK/2
	XintfRegs.XINTCNF2.bit.CLKMODE = 1;
	// Enable XCLKOUT Off
	XintfRegs.XINTCNF2.bit.CLKOFF = 1;

// No write buffering
	XintfRegs.XINTCNF2.bit.WRBUFF = 0;

// Make sure write buffer is empty before configuring buffering depth
	while(XintfRegs.XINTCNF2.bit.WLEVEL != 0);		// poll the WLEVEL bit
	XintfRegs.XINTCNF2.bit.WRBUFF = 0;			// No write buffering

//--- XBANK Register
// Example: Assume Zone 7 is slow, so add additional BCYC cycles whenever
// switching from Zone 7 to another Zone.  This will help avoid bus contention.
	XintfRegs.XBANK.bit.BCYC = 7;				// Add 7 cycles
	XintfRegs.XBANK.bit.BANK = 7;				// select zone 7
    
//--- Zone 0 Configuration
	XintfRegs.XTIMING0.bit.X2TIMING = 1;			// Timing scale factor
	XintfRegs.XTIMING0.bit.XSIZE = 3;			// 3 means 16-bit interface
	XintfRegs.XTIMING0.bit.READYMODE = 1; 			// XREADY is asynchronous
	XintfRegs.XTIMING0.bit.USEREADY = 0;			// Disable XREADY
	XintfRegs.XTIMING0.bit.XRDLEAD = 3;			// Read lead time
	XintfRegs.XTIMING0.bit.XRDACTIVE = 7;			// Read active time
	XintfRegs.XTIMING0.bit.XRDTRAIL = 3;			// Read trail time
	XintfRegs.XTIMING0.bit.XWRLEAD = 3;			// Write lead time
	XintfRegs.XTIMING0.bit.XWRACTIVE = 7;			// Write active time
	XintfRegs.XTIMING0.bit.XWRTRAIL = 3;			// Write trail time

//--- Zone 6 Configuration
	XintfRegs.XTIMING6.bit.X2TIMING = 1;			// Timing scale factor
	XintfRegs.XTIMING6.bit.XSIZE = 3;			// 3 means 16-bit interface
	XintfRegs.XTIMING6.bit.READYMODE = 1; 			// XREADY is asynchronous
	XintfRegs.XTIMING6.bit.USEREADY = 0;			// Disable XREADY
	XintfRegs.XTIMING6.bit.XRDLEAD = 3;			// Read lead time
	XintfRegs.XTIMING6.bit.XRDACTIVE = 7;			// Read active time
	XintfRegs.XTIMING6.bit.XRDTRAIL = 3;			// Read trail time
	XintfRegs.XTIMING6.bit.XWRLEAD = 3;			// Write lead time
	XintfRegs.XTIMING6.bit.XWRACTIVE = 7;			// Write active time
	XintfRegs.XTIMING6.bit.XWRTRAIL = 3;			// Write trail time

//--- Zone 7 Configuration
	XintfRegs.XTIMING7.bit.X2TIMING = 1;			// Timing scale factor
	XintfRegs.XTIMING7.bit.XSIZE = 3;			// 3 means 16-bit interface
	XintfRegs.XTIMING7.bit.READYMODE = 1; 			// XREADY is asynchronous
	XintfRegs.XTIMING7.bit.USEREADY = 0;			// Disable XREADY
	XintfRegs.XTIMING7.bit.XRDLEAD = 3;			// Read lead time
	XintfRegs.XTIMING7.bit.XRDACTIVE = 7;			// Read active time
	XintfRegs.XTIMING7.bit.XRDTRAIL = 3;			// Read trail time
	XintfRegs.XTIMING7.bit.XWRLEAD = 3;			// Write lead time
	XintfRegs.XTIMING7.bit.XWRACTIVE = 7;			// Write active time
	XintfRegs.XTIMING7.bit.XWRTRAIL = 3;			// Write trail time

//--- Finish up
	asm(" EDIS");						// Disable EALLOW protected register access

//--- Force a complete pipeline flush to ensure that the write to the last register
//    configured occurs before returning.  Safest thing to do is wait 8 full cycles.
	asm(" RPT #6 || NOP");
}

